# Cloudbeds Accounting
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `cloudbeds_accounting` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v0
- Package version: 1.4.0
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with Cloudbeds Accounting,
you can run the following:

```python

import cloudbeds_accounting
from cloudbeds_accounting.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.cloudbeds-stage.com
# See configuration.py for a list of all supported configuration parameters.
configuration = cloudbeds_accounting.Configuration(
    host = "https://api.cloudbeds-stage.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearerAuth
configuration = cloudbeds_accounting.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with cloudbeds_accounting.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = cloudbeds_accounting.AccountsReceivableLedgerApi(api_client)
    x_property_id = 56 # int | Property id
    accounts_receivable_ledger_id = 56 # int | Accounts Receivable ID
    reservation_id = 56 # int | Reservation ID

    try:
        api_response = api_instance.delete_accounts_receivable_ledger_reservation_balance_transfer(x_property_id, accounts_receivable_ledger_id, reservation_id)
        print("The response of AccountsReceivableLedgerApi->delete_accounts_receivable_ledger_reservation_balance_transfer:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountsReceivableLedgerApi->delete_accounts_receivable_ledger_reservation_balance_transfer: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.cloudbeds-stage.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsReceivableLedgerApi* | [**delete_accounts_receivable_ledger_reservation_balance_transfer**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#delete_accounts_receivable_ledger_reservation_balance_transfer) | **DELETE** /accounting/v1.0/accounts-receivable-ledgers/{accountsReceivableLedgerId}/reservation/{reservationId}/balance-transfer | 
*AccountsReceivableLedgerApi* | [**get_accounts_receivable_ledger_by_id**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#get_accounts_receivable_ledger_by_id) | **GET** /accounting/v1.0/accounts-receivable-ledgers/{accountsReceivableLedgerId} | 
*AccountsReceivableLedgerApi* | [**get_accounts_receivable_ledger_reservation_balance_transfer**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#get_accounts_receivable_ledger_reservation_balance_transfer) | **GET** /accounting/v1.0/accounts-receivable-ledgers/reservation/{reservationId}/balance-transfer | 
*AccountsReceivableLedgerApi* | [**get_accounts_receivable_ledger_totals**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#get_accounts_receivable_ledger_totals) | **GET** /accounting/v1.0/accounts-receivable-ledgers/totals | 
*AccountsReceivableLedgerApi* | [**get_accounts_receivable_ledger_transactions**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#get_accounts_receivable_ledger_transactions) | **GET** /accounting/v1.0/accounts-receivable-ledgers/{accountsReceivableLedgerId}/transactions | 
*AccountsReceivableLedgerApi* | [**get_accounts_receivable_ledgers**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#get_accounts_receivable_ledgers) | **GET** /accounting/v1.0/accounts-receivable-ledgers | 
*AccountsReceivableLedgerApi* | [**patch_accounts_receivable_ledger**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#patch_accounts_receivable_ledger) | **PATCH** /accounting/v1.0/accounts-receivable-ledgers | 
*AccountsReceivableLedgerApi* | [**post_accounts_receivable_ledger**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#post_accounts_receivable_ledger) | **POST** /accounting/v1.0/accounts-receivable-ledgers | 
*AccountsReceivableLedgerApi* | [**post_accounts_receivable_ledger_reservation_balance_transfer**](cloudbeds_accounting/docs/AccountsReceivableLedgerApi.md#post_accounts_receivable_ledger_reservation_balance_transfer) | **POST** /accounting/v1.0/accounts-receivable-ledgers/{accountsReceivableLedgerId}/reservation/{reservationId}/balance-transfer | 
*CustomGeneralLedgerCodesApi* | [**get_custom_general_ledger_codes**](cloudbeds_accounting/docs/CustomGeneralLedgerCodesApi.md#get_custom_general_ledger_codes) | **GET** /accounting/v1.0/custom-general-ledger-codes | 
*CustomGeneralLedgerCodesApi* | [**put_custom_general_ledger_codes**](cloudbeds_accounting/docs/CustomGeneralLedgerCodesApi.md#put_custom_general_ledger_codes) | **PUT** /accounting/v1.0/custom-general-ledger-codes | 
*CustomTransactionCodesApi* | [**get_custom_transaction_codes**](cloudbeds_accounting/docs/CustomTransactionCodesApi.md#get_custom_transaction_codes) | **GET** /accounting/v1.0/custom-transaction-codes | 
*CustomTransactionCodesApi* | [**initialize_custom_transaction_codes**](cloudbeds_accounting/docs/CustomTransactionCodesApi.md#initialize_custom_transaction_codes) | **POST** /accounting/v1.0/custom-transaction-codes/initialize | 
*CustomTransactionCodesApi* | [**put_custom_transaction_codes**](cloudbeds_accounting/docs/CustomTransactionCodesApi.md#put_custom_transaction_codes) | **PUT** /accounting/v1.0/custom-transaction-codes | 
*DepositsApi* | [**get_deposit_balance**](cloudbeds_accounting/docs/DepositsApi.md#get_deposit_balance) | **GET** /accounting/v1.0/deposits/balance | 
*DepositsApi* | [**get_deposit_transactions**](cloudbeds_accounting/docs/DepositsApi.md#get_deposit_transactions) | **GET** /accounting/v1.0/deposits/transactions | 
*DepositsApi* | [**post_deposits_transfer**](cloudbeds_accounting/docs/DepositsApi.md#post_deposits_transfer) | **POST** /accounting/v1.0/deposits/transfer | 
*InternalTransactionCodesApi* | [**get_internal_transaction_codes**](cloudbeds_accounting/docs/InternalTransactionCodesApi.md#get_internal_transaction_codes) | **GET** /accounting/v1.0/internal-transaction-codes | 
*TransactionsApi* | [**list_transactions**](cloudbeds_accounting/docs/TransactionsApi.md#list_transactions) | **POST** /accounting/v1.0/transactions | 
*TrialBalanceApi* | [**calculate_trial_balance**](cloudbeds_accounting/docs/TrialBalanceApi.md#calculate_trial_balance) | **POST** /accounting/v1.0/trial-balance/configuration/calculate | 
*TrialBalanceApi* | [**get_trial_balance_configuration**](cloudbeds_accounting/docs/TrialBalanceApi.md#get_trial_balance_configuration) | **GET** /accounting/v1.0/trial-balance/configuration | 
*TrialBalanceApi* | [**get_trial_balance_report**](cloudbeds_accounting/docs/TrialBalanceApi.md#get_trial_balance_report) | **GET** /accounting/v1.0/trial-balance/report | 
*TrialBalanceApi* | [**is_trial_balance_configured**](cloudbeds_accounting/docs/TrialBalanceApi.md#is_trial_balance_configured) | **GET** /accounting/v1.0/trial-balance/configuration/status | 
*TrialBalanceApi* | [**set_trial_balance**](cloudbeds_accounting/docs/TrialBalanceApi.md#set_trial_balance) | **POST** /accounting/v1.0/trial-balance/configuration | 


## Documentation For Models

 - [Account](cloudbeds_accounting/docs/Account.md)
 - [AccountCategory](cloudbeds_accounting/docs/AccountCategory.md)
 - [AccountsReceivableLedgerPaginated](cloudbeds_accounting/docs/AccountsReceivableLedgerPaginated.md)
 - [AccountsReceivableLedgerPatchRequest](cloudbeds_accounting/docs/AccountsReceivableLedgerPatchRequest.md)
 - [AccountsReceivableLedgerPostRequest](cloudbeds_accounting/docs/AccountsReceivableLedgerPostRequest.md)
 - [AccountsReceivableLedgerReservationBalanceTransferResponse](cloudbeds_accounting/docs/AccountsReceivableLedgerReservationBalanceTransferResponse.md)
 - [AccountsReceivableLedgerReservationBalanceTransferResponseTransaction](cloudbeds_accounting/docs/AccountsReceivableLedgerReservationBalanceTransferResponseTransaction.md)
 - [AccountsReceivableLedgerResponse](cloudbeds_accounting/docs/AccountsReceivableLedgerResponse.md)
 - [AccountsReceivableLedgerStatus](cloudbeds_accounting/docs/AccountsReceivableLedgerStatus.md)
 - [AccountsReceivableLedgerTotalsResponse](cloudbeds_accounting/docs/AccountsReceivableLedgerTotalsResponse.md)
 - [Action](cloudbeds_accounting/docs/Action.md)
 - [AndOrGroup](cloudbeds_accounting/docs/AndOrGroup.md)
 - [AndOrGroupAndInner](cloudbeds_accounting/docs/AndOrGroupAndInner.md)
 - [ApiAccountingError](cloudbeds_accounting/docs/ApiAccountingError.md)
 - [ApiErrorCode](cloudbeds_accounting/docs/ApiErrorCode.md)
 - [AsyncEventResponse](cloudbeds_accounting/docs/AsyncEventResponse.md)
 - [ChartOfAccountType](cloudbeds_accounting/docs/ChartOfAccountType.md)
 - [ConditionalOperator](cloudbeds_accounting/docs/ConditionalOperator.md)
 - [CustomGeneralLedgerCodeModel](cloudbeds_accounting/docs/CustomGeneralLedgerCodeModel.md)
 - [CustomGeneralLedgerCodesUpdateRequest](cloudbeds_accounting/docs/CustomGeneralLedgerCodesUpdateRequest.md)
 - [CustomTransactionCodesModel](cloudbeds_accounting/docs/CustomTransactionCodesModel.md)
 - [CustomTransactionCodesUpdateModel](cloudbeds_accounting/docs/CustomTransactionCodesUpdateModel.md)
 - [CustomTransactionCodesUpdateRequest](cloudbeds_accounting/docs/CustomTransactionCodesUpdateRequest.md)
 - [DepositBalanceResponse](cloudbeds_accounting/docs/DepositBalanceResponse.md)
 - [ExtendedTransactionPaginated](cloudbeds_accounting/docs/ExtendedTransactionPaginated.md)
 - [ExtendedTransactionResponse](cloudbeds_accounting/docs/ExtendedTransactionResponse.md)
 - [FieldFilter](cloudbeds_accounting/docs/FieldFilter.md)
 - [Filters](cloudbeds_accounting/docs/Filters.md)
 - [GetAccountsReceivableLedgerTotalsFilterParameter](cloudbeds_accounting/docs/GetAccountsReceivableLedgerTotalsFilterParameter.md)
 - [GetAccountsReceivableLedgerTransactionsFilterParameter](cloudbeds_accounting/docs/GetAccountsReceivableLedgerTransactionsFilterParameter.md)
 - [GetAccountsReceivableLedgersFilterParameter](cloudbeds_accounting/docs/GetAccountsReceivableLedgersFilterParameter.md)
 - [GetDepositTransactionsFilterParameter](cloudbeds_accounting/docs/GetDepositTransactionsFilterParameter.md)
 - [InternalTransactionCodeGroupEnum](cloudbeds_accounting/docs/InternalTransactionCodeGroupEnum.md)
 - [InternalTransactionCodeResponse](cloudbeds_accounting/docs/InternalTransactionCodeResponse.md)
 - [InternalTransactionCodesListResponse](cloudbeds_accounting/docs/InternalTransactionCodesListResponse.md)
 - [ListTransactionsPaginated](cloudbeds_accounting/docs/ListTransactionsPaginated.md)
 - [ListTransactionsRequest](cloudbeds_accounting/docs/ListTransactionsRequest.md)
 - [LogicalOperator](cloudbeds_accounting/docs/LogicalOperator.md)
 - [PageDetails](cloudbeds_accounting/docs/PageDetails.md)
 - [ReservationStatus](cloudbeds_accounting/docs/ReservationStatus.md)
 - [Sort](cloudbeds_accounting/docs/Sort.md)
 - [SortDirection](cloudbeds_accounting/docs/SortDirection.md)
 - [SourceKind](cloudbeds_accounting/docs/SourceKind.md)
 - [TransactionItemMappingModel](cloudbeds_accounting/docs/TransactionItemMappingModel.md)
 - [TransactionItemMappingRequest](cloudbeds_accounting/docs/TransactionItemMappingRequest.md)
 - [TransactionItemMappingUpdateModel](cloudbeds_accounting/docs/TransactionItemMappingUpdateModel.md)
 - [TransactionResponse](cloudbeds_accounting/docs/TransactionResponse.md)
 - [TransactionState](cloudbeds_accounting/docs/TransactionState.md)
 - [TransferDepositPostRequest](cloudbeds_accounting/docs/TransferDepositPostRequest.md)
 - [TrialBalanceConfigurationStatusResponse](cloudbeds_accounting/docs/TrialBalanceConfigurationStatusResponse.md)
 - [TrialBalanceReportCodeInfo](cloudbeds_accounting/docs/TrialBalanceReportCodeInfo.md)
 - [TrialBalanceReportGuestLedger](cloudbeds_accounting/docs/TrialBalanceReportGuestLedger.md)
 - [TrialBalanceReportLedgerBalances](cloudbeds_accounting/docs/TrialBalanceReportLedgerBalances.md)
 - [TrialBalanceReportResponse](cloudbeds_accounting/docs/TrialBalanceReportResponse.md)
 - [TrialBalanceReportSummary](cloudbeds_accounting/docs/TrialBalanceReportSummary.md)
 - [TrialBalanceRequest](cloudbeds_accounting/docs/TrialBalanceRequest.md)
 - [TrialBalanceResponse](cloudbeds_accounting/docs/TrialBalanceResponse.md)
 - [UserModel](cloudbeds_accounting/docs/UserModel.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)


## Author




